/**
 * Autoinstrument node.js express app and export to prometheus
 */
const api = require('@opentelemetry/api');
const opentelemetry = require('@opentelemetry/sdk-node');
const { NoopSpanProcessor } = require('@opentelemetry/sdk-trace-base');
const { PrometheusExporter } = require('@opentelemetry/exporter-prometheus');
const { HttpInstrumentation } = require('@opentelemetry/instrumentation-http');

const pPort = PrometheusExporter.DEFAULT_OPTIONS.port;
const pEndpoint = PrometheusExporter.DEFAULT_OPTIONS.endpoint;

const prometheusExporter = new PrometheusExporter(
    { preventServerStart: false, prefix: 'ghost' },
    () => { console.log(`>>>> Prometheus scrape endpoint: http://localhost:${pPort}${pEndpoint}`); }
);

const sdk = new opentelemetry.NodeSDK({
    metricReader: prometheusExporter,
    // traceExporter: new NoopSpanProcessor(),
    instrumentations: [ new HttpInstrumentation() ]
});

sdk.start();
console.log('>>>> OpenTelemetry SDK started');

process.on("SIGTERM", () => {
  sdk
    .shutdown()
    .then(
      () => console.log('>>>> SDK shut down successfully'),
      (err) => console.log('>>>> Error shutting down SDK', err)
    )
    .finally(() => process.exit(0));
});

